ApplyArgs

Struct ApplyArgs 

pub struct ApplyArgs {
    pub license_args: LicenseArgs,
    pub file_args: FileProcessingArgs,
    pub dry_run: Option<bool>,
    pub prefer_block: Option<bool>,
}

Fields

license_args: LicenseArgsfile_args: FileProcessingArgsdry_run: Option<bool>

Run without modification. See what would be changed.

prefer_block: Option<bool>

When applying headers, which kind of comment token the user wants Completely possible line or block doesn’t exist, in which case it falls back to the other.